@@ -35,14 +35,16 @@ class S3(BaseSession):
         self.bucket_name: str = ""
         self.path_list: List[str] = [""]
 
-    def set_s3_bucket(self, header: str = "") -> None:
+    def set_s3_bucket(self, header: str = "", no_progress: bool = False) -> None:
         """List bucket through fzf and let user select a bucket.
 
         :param header: header to display in fzf header
         :type header: str, optional
+        :param no_progress: don't display progress bar, useful for ls command
+        :type no_progress: bool, optional
         """
         fzf = Pyfzf()
-        with Spinner.spin(message="Fethcing s3 buckets ..."):
+        with Spinner.spin(message="Fetching s3 buckets ...", no_progress=no_progress):
             response = self.client.list_buckets()
         fzf.process_list(response["Buckets"], "Name")
         self.bucket_name = str(fzf.execute_fzf(header=header))
@@ -170,6 +172,7 @@ class S3(BaseSession):
         version: bool = False,
         multi_select: bool = False,
         deletemark: bool = False,
+        no_progress: bool = False,
     ) -> None:
         """List object within a bucket and let user select a object.
 
@@ -185,13 +188,17 @@ class S3(BaseSession):
         :type multi_select: bool, optional
         :param deletemark: show deletemark object in the list
         :type deletemark: bool, optional
+        :param no_progress: don't display progress bar, useful for ls command
+        :type no_progress: bool, optional
         :raises NoSelectionMade: when there is no selection made
         """
         fzf = Pyfzf()
 
         if not version:
             paginator = self.client.get_paginator("list_objects")
-            with Spinner.spin(message="Fetching s3 objects ..."):
+            with Spinner.spin(
+                message="Fetching s3 objects ...", no_progress=no_progress
+            ):
                 for result in paginator.paginate(Bucket=self.bucket_name):
                     for file in result.get("Contents", []):
                         if file.get("Key").endswith("/") or not file.get("Key"):
@@ -207,7 +214,9 @@ class S3(BaseSession):
 
         else:
             paginator = self.client.get_paginator("list_object_versions")
-            with Spinner.spin(message="Fetching s3 objects ..."):
+            with Spinner.spin(
+                message="Fetching s3 objects ...", no_progress=no_progress
+            ):
                 results = paginator.paginate(Bucket=self.bucket_name)
                 version_obj_genrator = self._uniq_object_generator(results, deletemark)
                 generated = False
@@ -231,6 +240,7 @@ class S3(BaseSession):
         select_all: bool = False,
         non_current: bool = False,
         multi_select: bool = True,
+        no_progress: bool = False,
     ) -> List[Dict[str, str]]:
         """List object versions through fzf.
         
@@ -246,6 +256,8 @@ class S3(BaseSession):
         :type non_current: bool, optional
         :param multi_select: allow multi selection
         :type multi_select: bool, optional
+        :param no_progress: don't display progress bar, useful for ls command
+        :type no_progress: bool, optional
         :return: list of selected versions
         :rtype: List[Dict[str, str]]
 
@@ -254,6 +266,7 @@ class S3(BaseSession):
         """
         bucket = bucket if bucket else self.bucket_name
         key_list: list = []
+        fzf = Pyfzf()
 
         if key:
             key_list.append(key)
@@ -262,24 +275,35 @@ class S3(BaseSession):
         selected_versions: list = []
         for key in key_list:
             response_generator: Union[list, Generator[Dict[str, str], None, None]] = []
-            paginator = self.client.get_paginator("list_object_versions")
-            for result in paginator.paginate(Bucket=bucket, Prefix=key):
-                response_generator = self._version_generator(
-                    result.get("Versions", []),
-                    result.get("DeleteMarkers", []),
-                    non_current,
-                    delete,
-                )
+            with Spinner.spin(
+                message="Fetching object versions ...", no_progress=no_progress
+            ):
+                paginator = self.client.get_paginator("list_object_versions")
+                for result in paginator.paginate(Bucket=bucket, Prefix=key):
+                    response_generator = self._version_generator(
+                        result.get("Versions", []),
+                        result.get("DeleteMarkers", []),
+                        non_current,
+                        delete,
+                    )
+                    if not select_all:
+                        fzf.process_list(
+                            response_generator,
+                            "VersionId",
+                            "Key",
+                            "IsLatest",
+                            "DeleteMarker",
+                            "LastModified",
+                        )
+                    else:
+                        selected_versions.extend(
+                            [
+                                {"Key": key, "VersionId": version.get("VersionId")}
+                                for version in response_generator
+                            ]
+                        )
+
             if not select_all:
-                fzf = Pyfzf()
-                fzf.process_list(
-                    response_generator,
-                    "VersionId",
-                    "Key",
-                    "IsLatest",
-                    "DeleteMarker",
-                    "LastModified",
-                )
                 if delete and multi_select:
                     for result in fzf.execute_fzf(multi_select=True):
                         selected_versions.append({"Key": key, "VersionId": result})
@@ -287,13 +311,6 @@ class S3(BaseSession):
                     selected_versions.append(
                         {"Key": key, "VersionId": str(fzf.execute_fzf())}
                     )
-            else:
-                selected_versions.extend(
-                    [
-                        {"Key": key, "VersionId": version.get("VersionId")}
-                        for version in response_generator
-                    ]
-                )
         return selected_versions
 
     def get_object_data(self, file_type: str = "") -> Dict[str, Any]:
